import wepy from "wepy";

var utilMd5 = require('../lib/md5.js'); 

const TUWX = 'https://tuwx.duowan.com'
const TUDUOWAN = 'https://tu.duowan.com/index.php'

class HttpClient {
    constructor() {

    }
    // 搜索文本框提示
    getSearchTip() {
        return new Promise((resolve, reject) => {
            wepy.request({
                    url: `${TUWX}/search/searchTip`
                }).then(({data}) => {
                    resolve(data.data)
                })
        })
    }
    //搜索接口
    getSearchRes(keyWord, page) {
        return new Promise((resolve, reject) => {
            wepy.request({
                    url: `${TUWX}/search/tus`,
                    data: {
                        keyWord,
                        page
                    }
                }).then(({data}) => {
                    resolve(data.data)
                })
        })
    }
    //单张图片接口
    getPic(id) {
        return new Promise((resolve, reject) => {
            wepy.request({
                    url: `${TUWX}/search/tu`,
                    data: {
                        id
                    }
                }).then(({data}) => {
                    resolve(data.data)
                })
        })
    }
    //推荐图集
    getRecommandList() {
        return new Promise((resolve, reject) => {
            wepy.request({
                url: `${TUDUOWAN}?r=api/AjaxWeiRecommendGallery`,
                data: {
                    page: 1,
                    pageSize: 30
                }
            }).then(({data}) => {
                resolve(data.gallerys)
            })
        })
    }
    //今日囧图 搞笑GIF
    getTodayList(page = 1, pageSize = 3) {
        return new Promise((resolve, reject) => {
            wepy.request({
                url: `${TUDUOWAN}?r=api/AjaxWeiNewestGallery`,
                data: {
                    page,
                    pageSize
                }
            }).then(({data}) => {
                resolve(data)
            })
        })
    }
    // 六个标签的图集详情
    // 0 => 搞笑GIF
    // 1 => 今日囧图
    // 2 => 吐槽囧图
    // 3 => 段子精选
    // 4 => 十万个冷知识
    // 5 => 日式冷笑话

    getTagList(page = 1, pageSize = 10, tagNum = 1) {
        return new Promise((resolve, reject) => {
            wepy.request({
                url: `${TUDUOWAN}?r=api/AjaxWeiAllGallerys`,
                data: {
                    page,
                    pageSize,
                    tagNum
                }
            }).then(({data}) => {
                resolve(data)
            })
        })
    }

    // 评论信息
    getCommentList(order, uniqid ,num, galleryId, size=10) {
        return new Promise((resolve, reject) => {
            wepy.request({
                    url: `https://comment3.duowan.com/index.php?r=comment/comment`,
                    data: {
                        order,
                        uniqid,
                        domain: 'tu.duowan.com',
                        url : `/gallery/${galleryId}.html`,
                        num: num,
                        size
                    }
                }).then((data) => {
                    resolve(data.data)
                })
        })
    }

    //评论前请求 
    sendTotal(commentItem) {
        let uniqid = commentItem.comment_uniqid
        let url = commentItem.comment_url.replace(/tu.duowan.com/,'')
        return new Promise((resolve, reject) => {
            wepy.request({
                url:'https://comment3.duowan.com/index.php?r=comment/totaljson',
                data: {
                    uniqid,
                    domain: 'tu.duowan.com',
                    url
                }
            }).then(({data}) => {
                resolve(data.show.content_key)
            })
        })
    }

    //添加评论
    addComment(uniqid, content, url, title, parent_id) {

        let loginData = wx.getStorageSync('loginData')
        let userInfo = wx.getStorageSync('userInfo')

        let md5 = utilMd5.md5(content)

        let sign = md5.substr(15, 6).toLowerCase()

        if(loginData && userInfo) {
            let lg_uid = loginData.uid
            let lg_openid = loginData.openId
            let lg_type = loginData.type
            let lg_token = loginData.token

            let nickname = userInfo.nickName
            let avatar = userInfo.avatarUrl
            
            let param = {}
            if(parent_id) {
                param = {
                    uniqid,
                    content,
                    url,
                    title,
                    sign,
                    parent_id,
                    domain: 'tu.duowan.com',
                    nickname,
                    avatar,
                    lg_uid,
                    lg_openid,
                    lg_type,
                    lg_token
                }
            } else {
                param = {
                    uniqid,
                    content,
                    url,
                    title,
                    sign,
                    domain: 'tu.duowan.com',
                    nickname,
                    avatar,
                    lg_uid,
                    lg_openid,
                    lg_type,
                    lg_token
                }
            }
            return new Promise((resolve, reject) => {
                wepy.request({
                    url:'https://comment3.duowan.com/index.php?r=comment/add',
                    data: param
                }).then(({data}) => {
                    resolve(data)
                })
            })

        } else {
            wepy.$instance.toLogin()
        }

    }
}

export default new HttpClient